# Form implementation generated from reading ui file 'src/eric7/QScintilla/ReplaceWidget.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_ReplaceWidget(object):
    def setupUi(self, ReplaceWidget):
        ReplaceWidget.setObjectName("ReplaceWidget")
        ReplaceWidget.resize(813, 54)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(ReplaceWidget.sizePolicy().hasHeightForWidth())
        ReplaceWidget.setSizePolicy(sizePolicy)
        self.gridLayout = QtWidgets.QGridLayout(ReplaceWidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.closeButton = QtWidgets.QToolButton(ReplaceWidget)
        self.closeButton.setText("")
        self.closeButton.setObjectName("closeButton")
        self.gridLayout.addWidget(self.closeButton, 0, 0, 1, 1)
        self.label = QtWidgets.QLabel(ReplaceWidget)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 1, 1, 1)
        self.findtextCombo = QtWidgets.QComboBox(ReplaceWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.findtextCombo.sizePolicy().hasHeightForWidth())
        self.findtextCombo.setSizePolicy(sizePolicy)
        self.findtextCombo.setMinimumSize(QtCore.QSize(300, 0))
        self.findtextCombo.setEditable(True)
        self.findtextCombo.setInsertPolicy(QtWidgets.QComboBox.InsertPolicy.InsertAtTop)
        self.findtextCombo.setDuplicatesEnabled(False)
        self.findtextCombo.setObjectName("findtextCombo")
        self.gridLayout.addWidget(self.findtextCombo, 0, 2, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSpacing(0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.findPrevButton = QtWidgets.QToolButton(ReplaceWidget)
        self.findPrevButton.setObjectName("findPrevButton")
        self.horizontalLayout.addWidget(self.findPrevButton)
        self.findNextButton = QtWidgets.QToolButton(ReplaceWidget)
        self.findNextButton.setObjectName("findNextButton")
        self.horizontalLayout.addWidget(self.findNextButton)
        self.extendButton = QtWidgets.QToolButton(ReplaceWidget)
        self.extendButton.setObjectName("extendButton")
        self.horizontalLayout.addWidget(self.extendButton)
        self.gridLayout.addLayout(self.horizontalLayout, 0, 3, 1, 1)
        self.caseCheckBox = QtWidgets.QCheckBox(ReplaceWidget)
        self.caseCheckBox.setObjectName("caseCheckBox")
        self.gridLayout.addWidget(self.caseCheckBox, 0, 4, 1, 1)
        self.wordCheckBox = QtWidgets.QCheckBox(ReplaceWidget)
        self.wordCheckBox.setObjectName("wordCheckBox")
        self.gridLayout.addWidget(self.wordCheckBox, 0, 5, 1, 1)
        self.regexpCheckBox = QtWidgets.QCheckBox(ReplaceWidget)
        self.regexpCheckBox.setObjectName("regexpCheckBox")
        self.gridLayout.addWidget(self.regexpCheckBox, 0, 6, 1, 1)
        self.label_2 = QtWidgets.QLabel(ReplaceWidget)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 1, 1, 1, 1)
        self.replacetextCombo = QtWidgets.QComboBox(ReplaceWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.replacetextCombo.sizePolicy().hasHeightForWidth())
        self.replacetextCombo.setSizePolicy(sizePolicy)
        self.replacetextCombo.setMinimumSize(QtCore.QSize(300, 0))
        self.replacetextCombo.setEditable(True)
        self.replacetextCombo.setInsertPolicy(QtWidgets.QComboBox.InsertPolicy.InsertAtTop)
        self.replacetextCombo.setDuplicatesEnabled(False)
        self.replacetextCombo.setObjectName("replacetextCombo")
        self.gridLayout.addWidget(self.replacetextCombo, 1, 2, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.replaceButton = QtWidgets.QToolButton(ReplaceWidget)
        self.replaceButton.setObjectName("replaceButton")
        self.horizontalLayout_2.addWidget(self.replaceButton)
        self.replaceSearchButton = QtWidgets.QToolButton(ReplaceWidget)
        self.replaceSearchButton.setObjectName("replaceSearchButton")
        self.horizontalLayout_2.addWidget(self.replaceSearchButton)
        self.replaceAllButton = QtWidgets.QToolButton(ReplaceWidget)
        self.replaceAllButton.setObjectName("replaceAllButton")
        self.horizontalLayout_2.addWidget(self.replaceAllButton)
        self.gridLayout.addLayout(self.horizontalLayout_2, 1, 3, 1, 1)
        self.wrapCheckBox = QtWidgets.QCheckBox(ReplaceWidget)
        self.wrapCheckBox.setObjectName("wrapCheckBox")
        self.gridLayout.addWidget(self.wrapCheckBox, 1, 4, 1, 1)
        self.selectionCheckBox = QtWidgets.QCheckBox(ReplaceWidget)
        self.selectionCheckBox.setObjectName("selectionCheckBox")
        self.gridLayout.addWidget(self.selectionCheckBox, 1, 5, 1, 1)
        self.label.setBuddy(self.findtextCombo)
        self.label_2.setBuddy(self.replacetextCombo)

        self.retranslateUi(ReplaceWidget)
        QtCore.QMetaObject.connectSlotsByName(ReplaceWidget)
        ReplaceWidget.setTabOrder(self.findtextCombo, self.replacetextCombo)
        ReplaceWidget.setTabOrder(self.replacetextCombo, self.caseCheckBox)
        ReplaceWidget.setTabOrder(self.caseCheckBox, self.wordCheckBox)
        ReplaceWidget.setTabOrder(self.wordCheckBox, self.regexpCheckBox)
        ReplaceWidget.setTabOrder(self.regexpCheckBox, self.wrapCheckBox)
        ReplaceWidget.setTabOrder(self.wrapCheckBox, self.selectionCheckBox)
        ReplaceWidget.setTabOrder(self.selectionCheckBox, self.extendButton)
        ReplaceWidget.setTabOrder(self.extendButton, self.findNextButton)
        ReplaceWidget.setTabOrder(self.findNextButton, self.findPrevButton)
        ReplaceWidget.setTabOrder(self.findPrevButton, self.replaceSearchButton)
        ReplaceWidget.setTabOrder(self.replaceSearchButton, self.replaceAllButton)
        ReplaceWidget.setTabOrder(self.replaceAllButton, self.replaceButton)
        ReplaceWidget.setTabOrder(self.replaceButton, self.closeButton)

    def retranslateUi(self, ReplaceWidget):
        _translate = QtCore.QCoreApplication.translate
        ReplaceWidget.setWindowTitle(_translate("ReplaceWidget", "Find and Replace"))
        self.closeButton.setToolTip(_translate("ReplaceWidget", "Press to close the window"))
        self.label.setText(_translate("ReplaceWidget", "&Find:"))
        self.findPrevButton.setToolTip(_translate("ReplaceWidget", "Press to find the previous occurrence"))
        self.findNextButton.setToolTip(_translate("ReplaceWidget", "Press to find the next occurrence"))
        self.extendButton.setToolTip(_translate("ReplaceWidget", "Press to extend the search to the whole word"))
        self.caseCheckBox.setText(_translate("ReplaceWidget", "&Match case"))
        self.wordCheckBox.setText(_translate("ReplaceWidget", "Whole &word"))
        self.regexpCheckBox.setText(_translate("ReplaceWidget", "Rege&xp"))
        self.label_2.setText(_translate("ReplaceWidget", "&Replace:"))
        self.replaceButton.setToolTip(_translate("ReplaceWidget", "Press to replace the selection"))
        self.replaceSearchButton.setToolTip(_translate("ReplaceWidget", "Press to replace the selection and search for the next occurence"))
        self.replaceAllButton.setToolTip(_translate("ReplaceWidget", "Press to replace all occurrences"))
        self.wrapCheckBox.setText(_translate("ReplaceWidget", "Wrap &around"))
        self.selectionCheckBox.setText(_translate("ReplaceWidget", "&Selection only"))



# Form implementation generated from reading ui file 'src/eric7/Plugins/VcsPlugins/vcsPySvn/SvnBlameDialog.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_SvnBlameDialog(object):
    def setupUi(self, SvnBlameDialog):
        SvnBlameDialog.setObjectName("SvnBlameDialog")
        SvnBlameDialog.resize(690, 750)
        SvnBlameDialog.setSizeGripEnabled(True)
        self.vboxlayout = QtWidgets.QVBoxLayout(SvnBlameDialog)
        self.vboxlayout.setObjectName("vboxlayout")
        self.blameList = QtWidgets.QTreeWidget(SvnBlameDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(6)
        sizePolicy.setHeightForWidth(self.blameList.sizePolicy().hasHeightForWidth())
        self.blameList.setSizePolicy(sizePolicy)
        self.blameList.setAlternatingRowColors(True)
        self.blameList.setSelectionMode(QtWidgets.QAbstractItemView.SelectionMode.NoSelection)
        self.blameList.setRootIsDecorated(False)
        self.blameList.setItemsExpandable(False)
        self.blameList.setObjectName("blameList")
        self.blameList.header().setStretchLastSection(False)
        self.vboxlayout.addWidget(self.blameList)
        self.errorGroup = QtWidgets.QGroupBox(SvnBlameDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.errorGroup.sizePolicy().hasHeightForWidth())
        self.errorGroup.setSizePolicy(sizePolicy)
        self.errorGroup.setObjectName("errorGroup")
        self.vboxlayout1 = QtWidgets.QVBoxLayout(self.errorGroup)
        self.vboxlayout1.setObjectName("vboxlayout1")
        self.errors = QtWidgets.QTextEdit(self.errorGroup)
        self.errors.setReadOnly(True)
        self.errors.setAcceptRichText(False)
        self.errors.setObjectName("errors")
        self.vboxlayout1.addWidget(self.errors)
        self.vboxlayout.addWidget(self.errorGroup)
        self.buttonBox = QtWidgets.QDialogButtonBox(SvnBlameDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Close)
        self.buttonBox.setObjectName("buttonBox")
        self.vboxlayout.addWidget(self.buttonBox)

        self.retranslateUi(SvnBlameDialog)
        QtCore.QMetaObject.connectSlotsByName(SvnBlameDialog)
        SvnBlameDialog.setTabOrder(self.blameList, self.errors)
        SvnBlameDialog.setTabOrder(self.errors, self.buttonBox)

    def retranslateUi(self, SvnBlameDialog):
        _translate = QtCore.QCoreApplication.translate
        SvnBlameDialog.setWindowTitle(_translate("SvnBlameDialog", "Subversion Blame"))
        self.blameList.headerItem().setText(0, _translate("SvnBlameDialog", "Revision"))
        self.blameList.headerItem().setText(1, _translate("SvnBlameDialog", "Author"))
        self.blameList.headerItem().setText(2, _translate("SvnBlameDialog", "Line"))
        self.errorGroup.setTitle(_translate("SvnBlameDialog", "Errors"))



# Form implementation generated from reading ui file 'src/eric7/Testing/TestingWidget.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_TestingWidget(object):
    def setupUi(self, TestingWidget):
        TestingWidget.setObjectName("TestingWidget")
        TestingWidget.resize(850, 700)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(TestingWidget)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.tabWidget = QtWidgets.QTabWidget(TestingWidget)
        self.tabWidget.setObjectName("tabWidget")
        self.parametersTab = QtWidgets.QWidget()
        self.parametersTab.setObjectName("parametersTab")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.parametersTab)
        self.verticalLayout.setObjectName("verticalLayout")
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.venvLabel = QtWidgets.QLabel(self.parametersTab)
        self.venvLabel.setObjectName("venvLabel")
        self.gridLayout_3.addWidget(self.venvLabel, 0, 0, 1, 1)
        self.venvComboBox = QtWidgets.QComboBox(self.parametersTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.venvComboBox.sizePolicy().hasHeightForWidth())
        self.venvComboBox.setSizePolicy(sizePolicy)
        self.venvComboBox.setObjectName("venvComboBox")
        self.gridLayout_3.addWidget(self.venvComboBox, 0, 1, 1, 2)
        self.label = QtWidgets.QLabel(self.parametersTab)
        self.label.setObjectName("label")
        self.gridLayout_3.addWidget(self.label, 1, 0, 1, 1)
        self.frameworkComboBox = QtWidgets.QComboBox(self.parametersTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frameworkComboBox.sizePolicy().hasHeightForWidth())
        self.frameworkComboBox.setSizePolicy(sizePolicy)
        self.frameworkComboBox.setObjectName("frameworkComboBox")
        self.gridLayout_3.addWidget(self.frameworkComboBox, 1, 1, 1, 1)
        self.versionsButton = QtWidgets.QToolButton(self.parametersTab)
        self.versionsButton.setObjectName("versionsButton")
        self.gridLayout_3.addWidget(self.versionsButton, 1, 2, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout_3)
        self.groupBox = QtWidgets.QGroupBox(self.parametersTab)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.discoverCheckBox = QtWidgets.QCheckBox(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.discoverCheckBox.sizePolicy().hasHeightForWidth())
        self.discoverCheckBox.setSizePolicy(sizePolicy)
        self.discoverCheckBox.setChecked(True)
        self.discoverCheckBox.setObjectName("discoverCheckBox")
        self.horizontalLayout_4.addWidget(self.discoverCheckBox)
        self.clearHistoriesButton = QtWidgets.QToolButton(self.groupBox)
        self.clearHistoriesButton.setObjectName("clearHistoriesButton")
        self.horizontalLayout_4.addWidget(self.clearHistoriesButton)
        self.gridLayout.addLayout(self.horizontalLayout_4, 0, 0, 1, 3)
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 1, 0, 1, 1)
        self.discoveryPicker = EricComboPathPicker(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.discoveryPicker.sizePolicy().hasHeightForWidth())
        self.discoveryPicker.setSizePolicy(sizePolicy)
        self.discoveryPicker.setFocusPolicy(QtCore.Qt.FocusPolicy.WheelFocus)
        self.discoveryPicker.setObjectName("discoveryPicker")
        self.gridLayout.addWidget(self.discoveryPicker, 1, 1, 1, 2)
        self.testsuiteLabel = QtWidgets.QLabel(self.groupBox)
        self.testsuiteLabel.setObjectName("testsuiteLabel")
        self.gridLayout.addWidget(self.testsuiteLabel, 2, 0, 1, 1)
        self.testsuitePicker = EricComboPathPicker(self.groupBox)
        self.testsuitePicker.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.testsuitePicker.sizePolicy().hasHeightForWidth())
        self.testsuitePicker.setSizePolicy(sizePolicy)
        self.testsuitePicker.setFocusPolicy(QtCore.Qt.FocusPolicy.WheelFocus)
        self.testsuitePicker.setObjectName("testsuitePicker")
        self.gridLayout.addWidget(self.testsuitePicker, 2, 1, 1, 2)
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 3, 0, 1, 1)
        self.testComboBox = QtWidgets.QComboBox(self.groupBox)
        self.testComboBox.setEnabled(False)
        self.testComboBox.setEditable(True)
        self.testComboBox.setObjectName("testComboBox")
        self.gridLayout.addWidget(self.testComboBox, 3, 1, 1, 2)
        self.label_5 = QtWidgets.QLabel(self.groupBox)
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 4, 0, 1, 1)
        self.testNamePatternEdit = QtWidgets.QLineEdit(self.groupBox)
        self.testNamePatternEdit.setObjectName("testNamePatternEdit")
        self.gridLayout.addWidget(self.testNamePatternEdit, 4, 1, 1, 2)
        self.label_4 = QtWidgets.QLabel(self.groupBox)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 5, 0, 1, 1)
        self.markerExpressionEdit = QtWidgets.QLineEdit(self.groupBox)
        self.markerExpressionEdit.setClearButtonEnabled(True)
        self.markerExpressionEdit.setObjectName("markerExpressionEdit")
        self.gridLayout.addWidget(self.markerExpressionEdit, 5, 1, 1, 1)
        self.showMarkersButton = QtWidgets.QToolButton(self.groupBox)
        self.showMarkersButton.setObjectName("showMarkersButton")
        self.gridLayout.addWidget(self.showMarkersButton, 5, 2, 1, 1)
        self.verticalLayout.addWidget(self.groupBox)
        self.optionsGroup = QtWidgets.QGroupBox(self.parametersTab)
        self.optionsGroup.setObjectName("optionsGroup")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.optionsGroup)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.coverageCheckBox = QtWidgets.QCheckBox(self.optionsGroup)
        self.coverageCheckBox.setObjectName("coverageCheckBox")
        self.gridLayout_2.addWidget(self.coverageCheckBox, 0, 0, 1, 1)
        self.coverageEraseCheckBox = QtWidgets.QCheckBox(self.optionsGroup)
        self.coverageEraseCheckBox.setEnabled(False)
        self.coverageEraseCheckBox.setObjectName("coverageEraseCheckBox")
        self.gridLayout_2.addWidget(self.coverageEraseCheckBox, 0, 1, 1, 1)
        self.failfastCheckBox = QtWidgets.QCheckBox(self.optionsGroup)
        self.failfastCheckBox.setObjectName("failfastCheckBox")
        self.gridLayout_2.addWidget(self.failfastCheckBox, 1, 0, 1, 1)
        self.verticalLayout_2.addLayout(self.gridLayout_2)
        self.verticalLayout.addWidget(self.optionsGroup)
        spacerItem = QtWidgets.QSpacerItem(20, 239, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout.addItem(spacerItem)
        self.tabWidget.addTab(self.parametersTab, "")
        self.resultsTab = QtWidgets.QWidget()
        self.resultsTab.setObjectName("resultsTab")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.resultsTab)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.progressGroupBox = QtWidgets.QGroupBox(self.resultsTab)
        self.progressGroupBox.setObjectName("progressGroupBox")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.progressGroupBox)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.progressProgressBar = QtWidgets.QProgressBar(self.progressGroupBox)
        self.progressProgressBar.setProperty("value", 0)
        self.progressProgressBar.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.progressProgressBar.setObjectName("progressProgressBar")
        self.verticalLayout_4.addWidget(self.progressProgressBar)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.progressCounterRunLabel = QtWidgets.QLabel(self.progressGroupBox)
        self.progressCounterRunLabel.setObjectName("progressCounterRunLabel")
        self.horizontalLayout_2.addWidget(self.progressCounterRunLabel)
        self.progressCounterRunCount = QtWidgets.QLabel(self.progressGroupBox)
        self.progressCounterRunCount.setText("0")
        self.progressCounterRunCount.setObjectName("progressCounterRunCount")
        self.horizontalLayout_2.addWidget(self.progressCounterRunCount)
        self.progressCounterRemLabel = QtWidgets.QLabel(self.progressGroupBox)
        self.progressCounterRemLabel.setObjectName("progressCounterRemLabel")
        self.horizontalLayout_2.addWidget(self.progressCounterRemLabel)
        self.progressCounterRemCount = QtWidgets.QLabel(self.progressGroupBox)
        self.progressCounterRemCount.setText("0")
        self.progressCounterRemCount.setObjectName("progressCounterRemCount")
        self.horizontalLayout_2.addWidget(self.progressCounterRemCount)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem1)
        self.verticalLayout_4.addLayout(self.horizontalLayout_2)
        self.verticalLayout_6.addWidget(self.progressGroupBox)
        self.resultsGroupBox = QtWidgets.QGroupBox(self.resultsTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.resultsGroupBox.sizePolicy().hasHeightForWidth())
        self.resultsGroupBox.setSizePolicy(sizePolicy)
        self.resultsGroupBox.setObjectName("resultsGroupBox")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.resultsGroupBox)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.statusLabel = QtWidgets.QLabel(self.resultsGroupBox)
        self.statusLabel.setText("")
        self.statusLabel.setObjectName("statusLabel")
        self.verticalLayout_5.addWidget(self.statusLabel)
        self.verticalLayout_6.addWidget(self.resultsGroupBox)
        self.tabWidget.addTab(self.resultsTab, "")
        self.verticalLayout_3.addWidget(self.tabWidget)
        self._4 = QtWidgets.QHBoxLayout()
        self._4.setObjectName("_4")
        self.sbLabel = QtWidgets.QLabel(TestingWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sbLabel.sizePolicy().hasHeightForWidth())
        self.sbLabel.setSizePolicy(sizePolicy)
        self.sbLabel.setObjectName("sbLabel")
        self._4.addWidget(self.sbLabel)
        spacerItem2 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self._4.addItem(spacerItem2)
        self.verticalLayout_3.addLayout(self._4)
        self.buttonBox = QtWidgets.QDialogButtonBox(TestingWidget)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Close)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout_3.addWidget(self.buttonBox)
        self.venvLabel.setBuddy(self.venvComboBox)
        self.label_3.setBuddy(self.discoveryPicker)
        self.testsuiteLabel.setBuddy(self.testsuitePicker)
        self.label_2.setBuddy(self.testComboBox)
        self.label_5.setBuddy(self.testComboBox)

        self.retranslateUi(TestingWidget)
        self.tabWidget.setCurrentIndex(0)
        self.buttonBox.accepted.connect(TestingWidget.close) # type: ignore
        self.buttonBox.rejected.connect(TestingWidget.close) # type: ignore
        self.discoverCheckBox.toggled['bool'].connect(self.discoveryPicker.setEnabled) # type: ignore
        self.discoverCheckBox.toggled['bool'].connect(self.testsuitePicker.setDisabled) # type: ignore
        self.discoverCheckBox.toggled['bool'].connect(self.testComboBox.setDisabled) # type: ignore
        self.coverageCheckBox.toggled['bool'].connect(self.coverageEraseCheckBox.setEnabled) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(TestingWidget)
        TestingWidget.setTabOrder(self.tabWidget, self.venvComboBox)
        TestingWidget.setTabOrder(self.venvComboBox, self.frameworkComboBox)
        TestingWidget.setTabOrder(self.frameworkComboBox, self.versionsButton)
        TestingWidget.setTabOrder(self.versionsButton, self.discoverCheckBox)
        TestingWidget.setTabOrder(self.discoverCheckBox, self.clearHistoriesButton)
        TestingWidget.setTabOrder(self.clearHistoriesButton, self.discoveryPicker)
        TestingWidget.setTabOrder(self.discoveryPicker, self.testsuitePicker)
        TestingWidget.setTabOrder(self.testsuitePicker, self.testComboBox)
        TestingWidget.setTabOrder(self.testComboBox, self.testNamePatternEdit)
        TestingWidget.setTabOrder(self.testNamePatternEdit, self.markerExpressionEdit)
        TestingWidget.setTabOrder(self.markerExpressionEdit, self.showMarkersButton)
        TestingWidget.setTabOrder(self.showMarkersButton, self.coverageCheckBox)
        TestingWidget.setTabOrder(self.coverageCheckBox, self.coverageEraseCheckBox)
        TestingWidget.setTabOrder(self.coverageEraseCheckBox, self.failfastCheckBox)

    def retranslateUi(self, TestingWidget):
        _translate = QtCore.QCoreApplication.translate
        TestingWidget.setWindowTitle(_translate("TestingWidget", "Testing"))
        self.venvLabel.setText(_translate("TestingWidget", "Virtual Environment:"))
        self.venvComboBox.setToolTip(_translate("TestingWidget", "Select the virtual environment to be used"))
        self.venvComboBox.setWhatsThis(_translate("TestingWidget", "<b>Virtual Environment</b>\\n<p>Enter the virtual environment to be used. Leave it empty to use the default environment, i.e. the one configured globally or per project.</p>"))
        self.label.setText(_translate("TestingWidget", "Test Framework:"))
        self.frameworkComboBox.setToolTip(_translate("TestingWidget", "Select the test framwork to be used"))
        self.versionsButton.setToolTip(_translate("TestingWidget", "Press to show the test framework versions"))
        self.groupBox.setTitle(_translate("TestingWidget", "Test Parameters"))
        self.discoverCheckBox.setToolTip(_translate("TestingWidget", "Select to discover tests automatically"))
        self.discoverCheckBox.setText(_translate("TestingWidget", "Discover tests (test modules must be importable)"))
        self.clearHistoriesButton.setToolTip(_translate("TestingWidget", "Press to clear the various histories"))
        self.label_3.setText(_translate("TestingWidget", "Discovery Start:"))
        self.discoveryPicker.setToolTip(_translate("TestingWidget", "Enter name of the directory at which to start the test file discovery"))
        self.discoveryPicker.setWhatsThis(_translate("TestingWidget", "<b>Discovery Start</b>\n"
"<p>Enter name of the directory at which to start the test file discovery.\n"
"Note that all test modules must be importable from this directory.</p>"))
        self.testsuiteLabel.setText(_translate("TestingWidget", "Test Filename:"))
        self.testsuitePicker.setToolTip(_translate("TestingWidget", "Enter name of file defining the testsuite"))
        self.testsuitePicker.setWhatsThis(_translate("TestingWidget", "<b>Testsuite</b><p>Enter the name of the file defining the testsuite. It should contain a method with a name given below. If no name is given, the \'suite()\' method will be tried. If no such method can be found, the module will be inspected for proper test cases.</p>"))
        self.label_2.setText(_translate("TestingWidget", "Test Name:"))
        self.testComboBox.setToolTip(_translate("TestingWidget", "Enter the test name. Leave empty to use the default name \"suite\"."))
        self.testComboBox.setWhatsThis(_translate("TestingWidget", "<b>Testname</b><p>Enter the name of the test to be performed. This name must follow the rules given by selecte test framework. If this field is empty, the default name of \"suite\" will be used.</p>"))
        self.label_5.setText(_translate("TestingWidget", "Test Name Pattern:"))
        self.testNamePatternEdit.setToolTip(_translate("TestingWidget", "Enter test name patterns (separated by a blank) or a test name expression"))
        self.label_4.setText(_translate("TestingWidget", "Marker Expression:"))
        self.markerExpressionEdit.setToolTip(_translate("TestingWidget", "Enter a marker expression or name to filter tests"))
        self.showMarkersButton.setToolTip(_translate("TestingWidget", "Press to show a window with the list of defined markers"))
        self.optionsGroup.setTitle(_translate("TestingWidget", "Run Parameters"))
        self.coverageCheckBox.setToolTip(_translate("TestingWidget", "Select whether coverage data should be collected"))
        self.coverageCheckBox.setText(_translate("TestingWidget", "Collect coverage data"))
        self.coverageEraseCheckBox.setToolTip(_translate("TestingWidget", "Select whether old coverage data should be erased"))
        self.coverageEraseCheckBox.setText(_translate("TestingWidget", "Erase coverage data"))
        self.failfastCheckBox.setToolTip(_translate("TestingWidget", "Select to stop the test run on the first error or failure"))
        self.failfastCheckBox.setText(_translate("TestingWidget", "Stop on First Error or Failure"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.parametersTab), _translate("TestingWidget", "Parameters"))
        self.progressGroupBox.setTitle(_translate("TestingWidget", "Progress"))
        self.progressProgressBar.setFormat(_translate("TestingWidget", "%v/%m Tests"))
        self.progressCounterRunLabel.setText(_translate("TestingWidget", "Run:"))
        self.progressCounterRunCount.setToolTip(_translate("TestingWidget", "Number of tests run"))
        self.progressCounterRemLabel.setText(_translate("TestingWidget", "Remaining:"))
        self.progressCounterRemCount.setToolTip(_translate("TestingWidget", "Number of tests to be run"))
        self.resultsGroupBox.setTitle(_translate("TestingWidget", "Results"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.resultsTab), _translate("TestingWidget", "Results"))
        self.sbLabel.setText(_translate("TestingWidget", "Idle"))
from eric7.EricWidgets.EricPathPicker import EricComboPathPicker



# Form implementation generated from reading ui file 'src/eric7/Plugins/VcsPlugins/vcsMercurial/HgRevisionSelectionDialog.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_HgRevisionSelectionDialog(object):
    def setupUi(self, HgRevisionSelectionDialog):
        HgRevisionSelectionDialog.setObjectName("HgRevisionSelectionDialog")
        HgRevisionSelectionDialog.resize(400, 342)
        HgRevisionSelectionDialog.setSizeGripEnabled(True)
        self.verticalLayout = QtWidgets.QVBoxLayout(HgRevisionSelectionDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(HgRevisionSelectionDialog)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.numberButton = QtWidgets.QRadioButton(self.groupBox)
        self.numberButton.setObjectName("numberButton")
        self.gridLayout.addWidget(self.numberButton, 0, 0, 1, 1)
        self.numberSpinBox = QtWidgets.QSpinBox(self.groupBox)
        self.numberSpinBox.setEnabled(False)
        self.numberSpinBox.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight)
        self.numberSpinBox.setMaximum(999999999)
        self.numberSpinBox.setObjectName("numberSpinBox")
        self.gridLayout.addWidget(self.numberSpinBox, 0, 1, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(158, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem, 0, 2, 1, 1)
        self.idButton = QtWidgets.QRadioButton(self.groupBox)
        self.idButton.setObjectName("idButton")
        self.gridLayout.addWidget(self.idButton, 1, 0, 1, 1)
        self.idEdit = QtWidgets.QLineEdit(self.groupBox)
        self.idEdit.setEnabled(False)
        self.idEdit.setClearButtonEnabled(True)
        self.idEdit.setObjectName("idEdit")
        self.gridLayout.addWidget(self.idEdit, 1, 1, 1, 2)
        self.tagButton = QtWidgets.QRadioButton(self.groupBox)
        self.tagButton.setObjectName("tagButton")
        self.gridLayout.addWidget(self.tagButton, 2, 0, 1, 1)
        self.tagCombo = QtWidgets.QComboBox(self.groupBox)
        self.tagCombo.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tagCombo.sizePolicy().hasHeightForWidth())
        self.tagCombo.setSizePolicy(sizePolicy)
        self.tagCombo.setEditable(True)
        self.tagCombo.setObjectName("tagCombo")
        self.gridLayout.addWidget(self.tagCombo, 2, 1, 1, 2)
        self.branchButton = QtWidgets.QRadioButton(self.groupBox)
        self.branchButton.setObjectName("branchButton")
        self.gridLayout.addWidget(self.branchButton, 3, 0, 1, 1)
        self.branchCombo = QtWidgets.QComboBox(self.groupBox)
        self.branchCombo.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.branchCombo.sizePolicy().hasHeightForWidth())
        self.branchCombo.setSizePolicy(sizePolicy)
        self.branchCombo.setEditable(True)
        self.branchCombo.setObjectName("branchCombo")
        self.gridLayout.addWidget(self.branchCombo, 3, 1, 1, 2)
        self.bookmarkButton = QtWidgets.QRadioButton(self.groupBox)
        self.bookmarkButton.setObjectName("bookmarkButton")
        self.gridLayout.addWidget(self.bookmarkButton, 4, 0, 1, 1)
        self.bookmarkCombo = QtWidgets.QComboBox(self.groupBox)
        self.bookmarkCombo.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bookmarkCombo.sizePolicy().hasHeightForWidth())
        self.bookmarkCombo.setSizePolicy(sizePolicy)
        self.bookmarkCombo.setEditable(True)
        self.bookmarkCombo.setObjectName("bookmarkCombo")
        self.gridLayout.addWidget(self.bookmarkCombo, 4, 1, 1, 2)
        self.expressionButton = QtWidgets.QRadioButton(self.groupBox)
        self.expressionButton.setObjectName("expressionButton")
        self.gridLayout.addWidget(self.expressionButton, 5, 0, 1, 1)
        self.expressionEdit = QtWidgets.QLineEdit(self.groupBox)
        self.expressionEdit.setEnabled(False)
        self.expressionEdit.setClearButtonEnabled(True)
        self.expressionEdit.setObjectName("expressionEdit")
        self.gridLayout.addWidget(self.expressionEdit, 5, 1, 1, 2)
        self.tipButton = QtWidgets.QRadioButton(self.groupBox)
        self.tipButton.setObjectName("tipButton")
        self.gridLayout.addWidget(self.tipButton, 6, 0, 1, 3)
        self.noneButton = QtWidgets.QRadioButton(self.groupBox)
        self.noneButton.setChecked(True)
        self.noneButton.setObjectName("noneButton")
        self.gridLayout.addWidget(self.noneButton, 7, 0, 1, 3)
        self.verticalLayout.addWidget(self.groupBox)
        self.buttonBox = QtWidgets.QDialogButtonBox(HgRevisionSelectionDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(HgRevisionSelectionDialog)
        self.buttonBox.accepted.connect(HgRevisionSelectionDialog.accept) # type: ignore
        self.buttonBox.rejected.connect(HgRevisionSelectionDialog.reject) # type: ignore
        self.numberButton.toggled['bool'].connect(self.numberSpinBox.setEnabled) # type: ignore
        self.idButton.toggled['bool'].connect(self.idEdit.setEnabled) # type: ignore
        self.tagButton.toggled['bool'].connect(self.tagCombo.setEnabled) # type: ignore
        self.branchButton.toggled['bool'].connect(self.branchCombo.setEnabled) # type: ignore
        self.bookmarkButton.toggled['bool'].connect(self.bookmarkCombo.setEnabled) # type: ignore
        self.expressionButton.toggled['bool'].connect(self.expressionEdit.setEnabled) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(HgRevisionSelectionDialog)
        HgRevisionSelectionDialog.setTabOrder(self.numberButton, self.numberSpinBox)
        HgRevisionSelectionDialog.setTabOrder(self.numberSpinBox, self.idButton)
        HgRevisionSelectionDialog.setTabOrder(self.idButton, self.idEdit)
        HgRevisionSelectionDialog.setTabOrder(self.idEdit, self.tagButton)
        HgRevisionSelectionDialog.setTabOrder(self.tagButton, self.tagCombo)
        HgRevisionSelectionDialog.setTabOrder(self.tagCombo, self.branchButton)
        HgRevisionSelectionDialog.setTabOrder(self.branchButton, self.branchCombo)
        HgRevisionSelectionDialog.setTabOrder(self.branchCombo, self.bookmarkButton)
        HgRevisionSelectionDialog.setTabOrder(self.bookmarkButton, self.bookmarkCombo)
        HgRevisionSelectionDialog.setTabOrder(self.bookmarkCombo, self.expressionButton)
        HgRevisionSelectionDialog.setTabOrder(self.expressionButton, self.expressionEdit)
        HgRevisionSelectionDialog.setTabOrder(self.expressionEdit, self.tipButton)
        HgRevisionSelectionDialog.setTabOrder(self.tipButton, self.noneButton)

    def retranslateUi(self, HgRevisionSelectionDialog):
        _translate = QtCore.QCoreApplication.translate
        HgRevisionSelectionDialog.setWindowTitle(_translate("HgRevisionSelectionDialog", "Mercurial Revision"))
        self.groupBox.setTitle(_translate("HgRevisionSelectionDialog", "Revision"))
        self.numberButton.setToolTip(_translate("HgRevisionSelectionDialog", "Select to specify a revision by number"))
        self.numberButton.setText(_translate("HgRevisionSelectionDialog", "Number"))
        self.numberSpinBox.setToolTip(_translate("HgRevisionSelectionDialog", "Enter a revision number"))
        self.idButton.setToolTip(_translate("HgRevisionSelectionDialog", "Select to specify a revision by changeset id"))
        self.idButton.setText(_translate("HgRevisionSelectionDialog", "Id:"))
        self.idEdit.setToolTip(_translate("HgRevisionSelectionDialog", "Enter a changeset id"))
        self.tagButton.setToolTip(_translate("HgRevisionSelectionDialog", "Select to specify a revision by a tag"))
        self.tagButton.setText(_translate("HgRevisionSelectionDialog", "Tag:"))
        self.tagCombo.setToolTip(_translate("HgRevisionSelectionDialog", "Enter a tag name"))
        self.branchButton.setToolTip(_translate("HgRevisionSelectionDialog", "Select to specify a revision by a branch"))
        self.branchButton.setText(_translate("HgRevisionSelectionDialog", "Branch:"))
        self.branchCombo.setToolTip(_translate("HgRevisionSelectionDialog", "Enter a branch name"))
        self.bookmarkButton.setToolTip(_translate("HgRevisionSelectionDialog", "Select to specify a revision by a bookmark"))
        self.bookmarkButton.setText(_translate("HgRevisionSelectionDialog", "Bookmark:"))
        self.bookmarkCombo.setToolTip(_translate("HgRevisionSelectionDialog", "Enter a bookmark name"))
        self.expressionButton.setText(_translate("HgRevisionSelectionDialog", "Expression:"))
        self.expressionEdit.setToolTip(_translate("HgRevisionSelectionDialog", "Enter a revision set expression"))
        self.tipButton.setToolTip(_translate("HgRevisionSelectionDialog", "Select tip revision of repository"))
        self.tipButton.setText(_translate("HgRevisionSelectionDialog", "TIP"))
        self.noneButton.setText(_translate("HgRevisionSelectionDialog", "No revision selected"))



# Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0
# For details: https://github.com/nedbat/coveragepy/blob/master/NOTICE.txt

"""HTML reporting for coverage.py."""

import datetime
import json
import os
import re
import shutil
import types

import coverage
from coverage.data import add_data_to_hash
from coverage.exceptions import NoDataError
from coverage.files import flat_rootname
from coverage.misc import ensure_dir, file_be_gone, Hasher, isolate_module, format_local_datetime
from coverage.misc import human_sorted, plural
from coverage.report import get_analysis_to_report
from coverage.results import Numbers
from coverage.templite import Templite

os = isolate_module(os)


def data_filename(fname):
    """Return the path to an "htmlfiles" data file of ours.
    """
    static_dir = os.path.join(os.path.dirname(__file__), "htmlfiles")
    static_filename = os.path.join(static_dir, fname)
    return static_filename


def read_data(fname):
    """Return the contents of a data file of ours."""
    with open(data_filename(fname)) as data_file:
        return data_file.read()


def write_html(fname, html):
    """Write `html` to `fname`, properly encoded."""
    html = re.sub(r"(\A\s+)|(\s+$)", "", html, flags=re.MULTILINE) + "\n"
    with open(fname, "wb") as fout:
        fout.write(html.encode('ascii', 'xmlcharrefreplace'))


class HtmlDataGeneration:
    """Generate structured data to be turned into HTML reports."""

    EMPTY = "(empty)"

    def __init__(self, cov):
        self.coverage = cov
        self.config = self.coverage.config
        data = self.coverage.get_data()
        self.has_arcs = data.has_arcs()
        if self.config.show_contexts:
            if data.measured_contexts() == {""}:
                self.coverage._warn("No contexts were measured")
        data.set_query_contexts(self.config.report_contexts)

    def data_for_file(self, fr, analysis):
        """Produce the data needed for one file's report."""
        if self.has_arcs:
            missing_branch_arcs = analysis.missing_branch_arcs()
            arcs_executed = analysis.arcs_executed()

        if self.config.show_contexts:
            contexts_by_lineno = analysis.data.contexts_by_lineno(analysis.filename)

        lines = []

        for lineno, tokens in enumerate(fr.source_token_lines(), start=1):
            # Figure out how to mark this line.
            category = None
            short_annotations = []
            long_annotations = []

            if lineno in analysis.excluded:
                category = 'exc'
            elif lineno in analysis.missing:
                category = 'mis'
            elif self.has_arcs and lineno in missing_branch_arcs:
                category = 'par'
                for b in missing_branch_arcs[lineno]:
                    if b < 0:
                        short_annotations.append("exit")
                    else:
                        short_annotations.append(b)
                    long_annotations.append(fr.missing_arc_description(lineno, b, arcs_executed))
            elif lineno in analysis.statements:
                category = 'run'

            contexts = contexts_label = None
            context_list = None
            if category and self.config.show_contexts:
                contexts = human_sorted(c or self.EMPTY for c in contexts_by_lineno.get(lineno, ()))
                if contexts == [self.EMPTY]:
                    contexts_label = self.EMPTY
                else:
                    contexts_label = f"{len(contexts)} ctx"
                    context_list = contexts

            lines.append(types.SimpleNamespace(
                tokens=tokens,
                number=lineno,
                category=category,
                statement=(lineno in analysis.statements),
                contexts=contexts,
                contexts_label=contexts_label,
                context_list=context_list,
                short_annotations=short_annotations,
                long_annotations=long_annotations,
            ))

        file_data = types.SimpleNamespace(
            relative_filename=fr.relative_filename(),
            nums=analysis.numbers,
            lines=lines,
        )

        return file_data


class FileToReport:
    """A file we're considering reporting."""
    def __init__(self, fr, analysis):
        self.fr = fr
        self.analysis = analysis
        self.rootname = flat_rootname(fr.relative_filename())
        self.html_filename = self.rootname + ".html"


class HtmlReporter:
    """HTML reporting."""

    # These files will be copied from the htmlfiles directory to the output
    # directory.
    STATIC_FILES = [
        "style.css",
        "coverage_html.js",
        "keybd_closed.png",
        "keybd_open.png",
        "favicon_32.png",
    ]

    def __init__(self, cov):
        self.coverage = cov
        self.config = self.coverage.config
        self.directory = self.config.html_dir

        self.skip_covered = self.config.html_skip_covered
        if self.skip_covered is None:
            self.skip_covered = self.config.skip_covered
        self.skip_empty = self.config.html_skip_empty
        if self.skip_empty is None:
            self.skip_empty = self.config.skip_empty
        self.skipped_covered_count = 0
        self.skipped_empty_count = 0

        title = self.config.html_title

        if self.config.extra_css:
            self.extra_css = os.path.basename(self.config.extra_css)
        else:
            self.extra_css = None

        self.data = self.coverage.get_data()
        self.has_arcs = self.data.has_arcs()

        self.file_summaries = []
        self.all_files_nums = []
        self.incr = IncrementalChecker(self.directory)
        self.datagen = HtmlDataGeneration(self.coverage)
        self.totals = Numbers(precision=self.config.precision)
        self.directory_was_empty = False
        self.first_fr = None
        self.final_fr = None

        self.template_globals = {
            # Functions available in the templates.
            'escape': escape,
            'pair': pair,
            'len': len,

            # Constants for this report.
            '__url__': coverage.__url__,
            '__version__': coverage.__version__,
            'title': title,
            'time_stamp': format_local_datetime(datetime.datetime.now()),
            'extra_css': self.extra_css,
            'has_arcs': self.has_arcs,
            'show_contexts': self.config.show_contexts,

            # Constants for all reports.
            # These css classes determine which lines are highlighted by default.
            'category': {
                'exc': 'exc show_exc',
                'mis': 'mis show_mis',
                'par': 'par run show_par',
                'run': 'run',
            },
        }
        self.pyfile_html_source = read_data("pyfile.html")
        self.source_tmpl = Templite(self.pyfile_html_source, self.template_globals)

    def report(self, morfs):
        """Generate an HTML report for `morfs`.

        `morfs` is a list of modules or file names.

        """
        # Read the status data and check that this run used the same
        # global data as the last run.
        self.incr.read()
        self.incr.check_global_data(self.config, self.pyfile_html_source)

        # Process all the files. For each page we need to supply a link
        # to the next and previous page.
        files_to_report = []

        for fr, analysis in get_analysis_to_report(self.coverage, morfs):
            ftr = FileToReport(fr, analysis)
            should = self.should_report_file(ftr)
            if should:
                files_to_report.append(ftr)
            else:
                file_be_gone(os.path.join(self.directory, ftr.html_filename))

        for i, ftr in enumerate(files_to_report):
            if i == 0:
                prev_html = "index.html"
            else:
                prev_html = files_to_report[i - 1].html_filename
            if i == len(files_to_report) - 1:
                next_html = "index.html"
            else:
                next_html = files_to_report[i + 1].html_filename
            self.write_html_file(ftr, prev_html, next_html)

        if not self.all_files_nums:
            raise NoDataError("No data to report.")

        self.totals = sum(self.all_files_nums)

        # Write the index file.
        if files_to_report:
            first_html = files_to_report[0].html_filename
            final_html = files_to_report[-1].html_filename
        else:
            first_html = final_html = "index.html"
        self.index_file(first_html, final_html)

        self.make_local_static_report_files()
        return self.totals.n_statements and self.totals.pc_covered

    def make_directory(self):
        """Make sure our htmlcov directory exists."""
        ensure_dir(self.directory)
        if not os.listdir(self.directory):
            self.directory_was_empty = True

    def make_local_static_report_files(self):
        """Make local instances of static files for HTML report."""
        # The files we provide must always be copied.
        for static in self.STATIC_FILES:
            shutil.copyfile(data_filename(static), os.path.join(self.directory, static))

        # Only write the .gitignore file if the directory was originally empty.
        # .gitignore can't be copied from the source tree because it would
        # prevent the static files from being checked in.
        if self.directory_was_empty:
            with open(os.path.join(self.directory, ".gitignore"), "w") as fgi:
                fgi.write("# Created by coverage.py\n*\n")

        # The user may have extra CSS they want copied.
        if self.extra_css:
            shutil.copyfile(self.config.extra_css, os.path.join(self.directory, self.extra_css))

    def should_report_file(self, ftr):
        """Determine if we'll report this file."""
        # Get the numbers for this file.
        nums = ftr.analysis.numbers
        self.all_files_nums.append(nums)

        if self.skip_covered:
            # Don't report on 100% files.
            no_missing_lines = (nums.n_missing == 0)
            no_missing_branches = (nums.n_partial_branches == 0)
            if no_missing_lines and no_missing_branches:
                # If there's an existing file, remove it.
                self.skipped_covered_count += 1
                return False

        if self.skip_empty:
            # Don't report on empty files.
            if nums.n_statements == 0:
                self.skipped_empty_count += 1
                return False

        return True

    def write_html_file(self, ftr, prev_html, next_html):
        """Generate an HTML file for one source file."""
        self.make_directory()

        # Find out if the file on disk is already correct.
        if self.incr.can_skip_file(self.data, ftr.fr, ftr.rootname):
            self.file_summaries.append(self.incr.index_info(ftr.rootname))
            return

        # Write the HTML page for this file.
        file_data = self.datagen.data_for_file(ftr.fr, ftr.analysis)
        for ldata in file_data.lines:
            # Build the HTML for the line.
            html = []
            for tok_type, tok_text in ldata.tokens:
                if tok_type == "ws":
                    html.append(escape(tok_text))
                else:
                    tok_html = escape(tok_text) or '&nbsp;'
                    html.append(
                        f'<span class="{tok_type}">{tok_html}</span>'
                    )
            ldata.html = ''.join(html)

            if ldata.short_annotations:
                # 202F is NARROW NO-BREAK SPACE.
                # 219B is RIGHTWARDS ARROW WITH STROKE.
                ldata.annotate = ",&nbsp;&nbsp; ".join(
                    f"{ldata.number}&#x202F;&#x219B;&#x202F;{d}"
                    for d in ldata.short_annotations
                )
            else:
                ldata.annotate = None

            if ldata.long_annotations:
                longs = ldata.long_annotations
                if len(longs) == 1:
                    ldata.annotate_long = longs[0]
                else:
                    ldata.annotate_long = "{:d} missed branches: {}".format(
                        len(longs),
                        ", ".join(
                            f"{num:d}) {ann_long}"
                            for num, ann_long in enumerate(longs, start=1)
                        ),
                    )
            else:
                ldata.annotate_long = None

            css_classes = []
            if ldata.category:
                css_classes.append(self.template_globals['category'][ldata.category])
            ldata.css_class = ' '.join(css_classes) or "pln"

        html_path = os.path.join(self.directory, ftr.html_filename)
        html = self.source_tmpl.render({
            **file_data.__dict__,
            'prev_html': prev_html,
            'next_html': next_html,
        })
        write_html(html_path, html)

        # Save this file's information for the index file.
        index_info = {
            'nums': ftr.analysis.numbers,
            'html_filename': ftr.html_filename,
            'relative_filename': ftr.fr.relative_filename(),
        }
        self.file_summaries.append(index_info)
        self.incr.set_index_info(ftr.rootname, index_info)

    def index_file(self, first_html, final_html):
        """Write the index.html file for this report."""
        self.make_directory()
        index_tmpl = Templite(read_data("index.html"), self.template_globals)

        skipped_covered_msg = skipped_empty_msg = ""
        if self.skipped_covered_count:
            n = self.skipped_covered_count
            skipped_covered_msg = f"{n} file{plural(n)} skipped due to complete coverage."
        if self.skipped_empty_count:
            n = self.skipped_empty_count
            skipped_empty_msg = f"{n} empty file{plural(n)} skipped."

        html = index_tmpl.render({
            'files': self.file_summaries,
            'totals': self.totals,
            'skipped_covered_msg': skipped_covered_msg,
            'skipped_empty_msg': skipped_empty_msg,
            'first_html': first_html,
            'final_html': final_html,
        })

        index_file = os.path.join(self.directory, "index.html")
        write_html(index_file, html)
        self.coverage._message(f"Wrote HTML report to {index_file}")

        # Write the latest hashes for next time.
        self.incr.write()


class IncrementalChecker:
    """Logic and data to support incremental reporting."""

    STATUS_FILE = "status.json"
    STATUS_FORMAT = 2

    #           pylint: disable=wrong-spelling-in-comment,useless-suppression
    #  The data looks like:
    #
    #  {
    #      "format": 2,
    #      "globals": "540ee119c15d52a68a53fe6f0897346d",
    #      "version": "4.0a1",
    #      "files": {
    #          "cogapp___init__": {
    #              "hash": "e45581a5b48f879f301c0f30bf77a50c",
    #              "index": {
    #                  "html_filename": "cogapp___init__.html",
    #                  "relative_filename": "cogapp/__init__",
    #                  "nums": [ 1, 14, 0, 0, 0, 0, 0 ]
    #              }
    #          },
    #          ...
    #          "cogapp_whiteutils": {
    #              "hash": "8504bb427fc488c4176809ded0277d51",
    #              "index": {
    #                  "html_filename": "cogapp_whiteutils.html",
    #                  "relative_filename": "cogapp/whiteutils",
    #                  "nums": [ 1, 59, 0, 1, 28, 2, 2 ]
    #              }
    #          }
    #      }
    #  }

    def __init__(self, directory):
        self.directory = directory
        self.reset()

    def reset(self):
        """Initialize to empty. Causes all files to be reported."""
        self.globals = ''
        self.files = {}

    def read(self):
        """Read the information we stored last time."""
        usable = False
        try:
            status_file = os.path.join(self.directory, self.STATUS_FILE)
            with open(status_file) as fstatus:
                status = json.load(fstatus)
        except (OSError, ValueError):
            usable = False
        else:
            usable = True
            if status['format'] != self.STATUS_FORMAT:
                usable = False
            elif status['version'] != coverage.__version__:
                usable = False

        if usable:
            self.files = {}
            for filename, fileinfo in status['files'].items():
                fileinfo['index']['nums'] = Numbers(*fileinfo['index']['nums'])
                self.files[filename] = fileinfo
            self.globals = status['globals']
        else:
            self.reset()

    def write(self):
        """Write the current status."""
        status_file = os.path.join(self.directory, self.STATUS_FILE)
        files = {}
        for filename, fileinfo in self.files.items():
            fileinfo['index']['nums'] = fileinfo['index']['nums'].init_args()
            files[filename] = fileinfo

        status = {
            'format': self.STATUS_FORMAT,
            'version': coverage.__version__,
            'globals': self.globals,
            'files': files,
        }
        with open(status_file, "w") as fout:
            json.dump(status, fout, separators=(',', ':'))

    def check_global_data(self, *data):
        """Check the global data that can affect incremental reporting."""
        m = Hasher()
        for d in data:
            m.update(d)
        these_globals = m.hexdigest()
        if self.globals != these_globals:
            self.reset()
            self.globals = these_globals

    def can_skip_file(self, data, fr, rootname):
        """Can we skip reporting this file?

        `data` is a CoverageData object, `fr` is a `FileReporter`, and
        `rootname` is the name being used for the file.
        """
        m = Hasher()
        m.update(fr.source().encode('utf-8'))
        add_data_to_hash(data, fr.filename, m)
        this_hash = m.hexdigest()

        that_hash = self.file_hash(rootname)

        if this_hash == that_hash:
            # Nothing has changed to require the file to be reported again.
            return True
        else:
            self.set_file_hash(rootname, this_hash)
            return False

    def file_hash(self, fname):
        """Get the hash of `fname`'s contents."""
        return self.files.get(fname, {}).get('hash', '')

    def set_file_hash(self, fname, val):
        """Set the hash of `fname`'s contents."""
        self.files.setdefault(fname, {})['hash'] = val

    def index_info(self, fname):
        """Get the information for index.html for `fname`."""
        return self.files.get(fname, {}).get('index', {})

    def set_index_info(self, fname, info):
        """Set the information for index.html for `fname`."""
        self.files.setdefault(fname, {})['index'] = info


# Helpers for templates and generating HTML

def escape(t):
    """HTML-escape the text in `t`.

    This is only suitable for HTML text, not attributes.

    """
    # Convert HTML special chars into HTML entities.
    return t.replace("&", "&amp;").replace("<", "&lt;")


def pair(ratio):
    """Format a pair of numbers so JavaScript can read them in an attribute."""
    return "%s %s" % ratio



# Form implementation generated from reading ui file 'src/eric7/CodeFormatting/FormattingDiffWidget.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_FormattingDiffWidget(object):
    def setupUi(self, FormattingDiffWidget):
        FormattingDiffWidget.setObjectName("FormattingDiffWidget")
        FormattingDiffWidget.resize(700, 700)
        self.verticalLayout = QtWidgets.QVBoxLayout(FormattingDiffWidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.diffEdit = QtWidgets.QPlainTextEdit(FormattingDiffWidget)
        self.diffEdit.setLineWrapMode(QtWidgets.QPlainTextEdit.LineWrapMode.NoWrap)
        self.diffEdit.setReadOnly(True)
        self.diffEdit.setTabStopDistance(8.0)
        self.diffEdit.setObjectName("diffEdit")
        self.verticalLayout.addWidget(self.diffEdit)
        self.buttonBox = QtWidgets.QDialogButtonBox(FormattingDiffWidget)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Close)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(FormattingDiffWidget)
        self.buttonBox.rejected.connect(FormattingDiffWidget.close) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(FormattingDiffWidget)

    def retranslateUi(self, FormattingDiffWidget):
        _translate = QtCore.QCoreApplication.translate
        FormattingDiffWidget.setWindowTitle(_translate("FormattingDiffWidget", "Reformatting Differences"))



# Form implementation generated from reading ui file 'src/eric7/DataViews/PyCoverageJsonReportDialog.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_PyCoverageJsonReportDialog(object):
    def setupUi(self, PyCoverageJsonReportDialog):
        PyCoverageJsonReportDialog.setObjectName("PyCoverageJsonReportDialog")
        PyCoverageJsonReportDialog.resize(500, 98)
        PyCoverageJsonReportDialog.setSizeGripEnabled(True)
        self.gridLayout = QtWidgets.QGridLayout(PyCoverageJsonReportDialog)
        self.gridLayout.setObjectName("gridLayout")
        self.compactCheckBox = QtWidgets.QCheckBox(PyCoverageJsonReportDialog)
        self.compactCheckBox.setChecked(True)
        self.compactCheckBox.setObjectName("compactCheckBox")
        self.gridLayout.addWidget(self.compactCheckBox, 1, 0, 1, 2)
        self.label_2 = QtWidgets.QLabel(PyCoverageJsonReportDialog)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 0, 0, 1, 1)
        self.outputFilePicker = EricPathPicker(PyCoverageJsonReportDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.outputFilePicker.sizePolicy().hasHeightForWidth())
        self.outputFilePicker.setSizePolicy(sizePolicy)
        self.outputFilePicker.setFocusPolicy(QtCore.Qt.FocusPolicy.StrongFocus)
        self.outputFilePicker.setObjectName("outputFilePicker")
        self.gridLayout.addWidget(self.outputFilePicker, 0, 1, 1, 1)
        self.buttonBox = QtWidgets.QDialogButtonBox(PyCoverageJsonReportDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 2, 0, 1, 2)

        self.retranslateUi(PyCoverageJsonReportDialog)
        self.buttonBox.accepted.connect(PyCoverageJsonReportDialog.accept) # type: ignore
        self.buttonBox.rejected.connect(PyCoverageJsonReportDialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(PyCoverageJsonReportDialog)

    def retranslateUi(self, PyCoverageJsonReportDialog):
        _translate = QtCore.QCoreApplication.translate
        PyCoverageJsonReportDialog.setWindowTitle(_translate("PyCoverageJsonReportDialog", "JSON Report"))
        self.compactCheckBox.setToolTip(_translate("PyCoverageJsonReportDialog", "Select to create the report using the compact format"))
        self.compactCheckBox.setText(_translate("PyCoverageJsonReportDialog", "Compact Format"))
        self.label_2.setText(_translate("PyCoverageJsonReportDialog", "Output File:"))
        self.outputFilePicker.setToolTip(_translate("PyCoverageJsonReportDialog", "Enter the path of the output file"))
from eric7.EricWidgets.EricPathPicker import EricPathPicker



# Form implementation generated from reading ui file 'src/eric7/CycloneDXInterface/CycloneDXMetaDataDialog.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_CycloneDXMetaDataDialog(object):
    def setupUi(self, CycloneDXMetaDataDialog):
        CycloneDXMetaDataDialog.setObjectName("CycloneDXMetaDataDialog")
        CycloneDXMetaDataDialog.resize(600, 600)
        CycloneDXMetaDataDialog.setSizeGripEnabled(True)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(CycloneDXMetaDataDialog)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.groupBox = QtWidgets.QGroupBox(CycloneDXMetaDataDialog)
        self.groupBox.setObjectName("groupBox")
        self.formLayout = QtWidgets.QFormLayout(self.groupBox)
        self.formLayout.setObjectName("formLayout")
        self.nameLabel = QtWidgets.QLabel(self.groupBox)
        self.nameLabel.setObjectName("nameLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.nameLabel)
        self.nameEdit = QtWidgets.QLineEdit(self.groupBox)
        self.nameEdit.setClearButtonEnabled(True)
        self.nameEdit.setObjectName("nameEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.nameEdit)
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label)
        self.typeComboBox = QtWidgets.QComboBox(self.groupBox)
        self.typeComboBox.setObjectName("typeComboBox")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.typeComboBox)
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setObjectName("label_2")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_2)
        self.versionEdit = QtWidgets.QLineEdit(self.groupBox)
        self.versionEdit.setClearButtonEnabled(True)
        self.versionEdit.setObjectName("versionEdit")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.ItemRole.FieldRole, self.versionEdit)
        self.descriptionLabel = QtWidgets.QLabel(self.groupBox)
        self.descriptionLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignTop)
        self.descriptionLabel.setObjectName("descriptionLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.ItemRole.LabelRole, self.descriptionLabel)
        self.descriptionEdit = EricSpellCheckedTextEdit(self.groupBox)
        self.descriptionEdit.setTabChangesFocus(True)
        self.descriptionEdit.setAcceptRichText(False)
        self.descriptionEdit.setObjectName("descriptionEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.ItemRole.FieldRole, self.descriptionEdit)
        self.verticalLayout_2.addWidget(self.groupBox)
        self.groupBox_2 = QtWidgets.QGroupBox(CycloneDXMetaDataDialog)
        self.groupBox_2.setObjectName("groupBox_2")
        self.formLayout_2 = QtWidgets.QFormLayout(self.groupBox_2)
        self.formLayout_2.setObjectName("formLayout_2")
        self.authorLabel = QtWidgets.QLabel(self.groupBox_2)
        self.authorLabel.setObjectName("authorLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.authorLabel)
        self.authorEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.authorEdit.setClearButtonEnabled(True)
        self.authorEdit.setObjectName("authorEdit")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.authorEdit)
        self.emailLabel = QtWidgets.QLabel(self.groupBox_2)
        self.emailLabel.setObjectName("emailLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.emailLabel)
        self.emailEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.emailEdit.setClearButtonEnabled(True)
        self.emailEdit.setObjectName("emailEdit")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.emailEdit)
        self.verticalLayout_2.addWidget(self.groupBox_2)
        self.groupBox_3 = QtWidgets.QGroupBox(CycloneDXMetaDataDialog)
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout.setObjectName("verticalLayout")
        self.licenseComboBox = QtWidgets.QComboBox(self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.licenseComboBox.sizePolicy().hasHeightForWidth())
        self.licenseComboBox.setSizePolicy(sizePolicy)
        self.licenseComboBox.setEditable(True)
        self.licenseComboBox.setObjectName("licenseComboBox")
        self.verticalLayout.addWidget(self.licenseComboBox)
        self.verticalLayout_2.addWidget(self.groupBox_3)
        self.groupBox_4 = QtWidgets.QGroupBox(CycloneDXMetaDataDialog)
        self.groupBox_4.setObjectName("groupBox_4")
        self.formLayout_3 = QtWidgets.QFormLayout(self.groupBox_4)
        self.formLayout_3.setObjectName("formLayout_3")
        self.label_3 = QtWidgets.QLabel(self.groupBox_4)
        self.label_3.setObjectName("label_3")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_3)
        self.manufacturerEdit = QtWidgets.QLineEdit(self.groupBox_4)
        self.manufacturerEdit.setClearButtonEnabled(True)
        self.manufacturerEdit.setObjectName("manufacturerEdit")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.manufacturerEdit)
        self.label_4 = QtWidgets.QLabel(self.groupBox_4)
        self.label_4.setObjectName("label_4")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_4)
        self.supplierEdit = QtWidgets.QLineEdit(self.groupBox_4)
        self.supplierEdit.setClearButtonEnabled(True)
        self.supplierEdit.setObjectName("supplierEdit")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.supplierEdit)
        self.verticalLayout_2.addWidget(self.groupBox_4)
        self.buttonBox = QtWidgets.QDialogButtonBox(CycloneDXMetaDataDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout_2.addWidget(self.buttonBox)
        self.nameLabel.setBuddy(self.nameEdit)
        self.descriptionLabel.setBuddy(self.descriptionEdit)
        self.authorLabel.setBuddy(self.authorEdit)
        self.emailLabel.setBuddy(self.emailEdit)

        self.retranslateUi(CycloneDXMetaDataDialog)
        self.buttonBox.accepted.connect(CycloneDXMetaDataDialog.accept) # type: ignore
        self.buttonBox.rejected.connect(CycloneDXMetaDataDialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(CycloneDXMetaDataDialog)
        CycloneDXMetaDataDialog.setTabOrder(self.nameEdit, self.typeComboBox)
        CycloneDXMetaDataDialog.setTabOrder(self.typeComboBox, self.versionEdit)
        CycloneDXMetaDataDialog.setTabOrder(self.versionEdit, self.descriptionEdit)
        CycloneDXMetaDataDialog.setTabOrder(self.descriptionEdit, self.authorEdit)
        CycloneDXMetaDataDialog.setTabOrder(self.authorEdit, self.emailEdit)
        CycloneDXMetaDataDialog.setTabOrder(self.emailEdit, self.licenseComboBox)
        CycloneDXMetaDataDialog.setTabOrder(self.licenseComboBox, self.manufacturerEdit)
        CycloneDXMetaDataDialog.setTabOrder(self.manufacturerEdit, self.supplierEdit)

    def retranslateUi(self, CycloneDXMetaDataDialog):
        _translate = QtCore.QCoreApplication.translate
        CycloneDXMetaDataDialog.setWindowTitle(_translate("CycloneDXMetaDataDialog", "SBOM Meta Data"))
        self.groupBox.setTitle(_translate("CycloneDXMetaDataDialog", "Component"))
        self.nameLabel.setText(_translate("CycloneDXMetaDataDialog", "Name:"))
        self.nameEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter the component name"))
        self.label.setText(_translate("CycloneDXMetaDataDialog", "Type:"))
        self.typeComboBox.setToolTip(_translate("CycloneDXMetaDataDialog", "Select the component type"))
        self.label_2.setText(_translate("CycloneDXMetaDataDialog", "Version:"))
        self.versionEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter the version number"))
        self.descriptionLabel.setText(_translate("CycloneDXMetaDataDialog", "Description:"))
        self.descriptionEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter a description of the component"))
        self.groupBox_2.setTitle(_translate("CycloneDXMetaDataDialog", "Author"))
        self.authorLabel.setText(_translate("CycloneDXMetaDataDialog", "Name:"))
        self.authorEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter author\'s name"))
        self.emailLabel.setText(_translate("CycloneDXMetaDataDialog", "Email:"))
        self.emailEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter author\'s email"))
        self.groupBox_3.setTitle(_translate("CycloneDXMetaDataDialog", "License"))
        self.licenseComboBox.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter or select the license"))
        self.groupBox_4.setTitle(_translate("CycloneDXMetaDataDialog", "Various"))
        self.label_3.setText(_translate("CycloneDXMetaDataDialog", "Manufacturer:"))
        self.manufacturerEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter the name of the manufacturer"))
        self.label_4.setText(_translate("CycloneDXMetaDataDialog", "Supplier:"))
        self.supplierEdit.setToolTip(_translate("CycloneDXMetaDataDialog", "Enter the name of the supplier"))
from eric7.EricWidgets.EricSpellCheckedTextEdit import EricSpellCheckedTextEdit



# Form implementation generated from reading ui file 'src/eric7/CodeFormatting/IsortFormattingDialog.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_IsortFormattingDialog(object):
    def setupUi(self, IsortFormattingDialog):
        IsortFormattingDialog.setObjectName("IsortFormattingDialog")
        IsortFormattingDialog.resize(700, 650)
        IsortFormattingDialog.setSizeGripEnabled(True)
        self.verticalLayout = QtWidgets.QVBoxLayout(IsortFormattingDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.label_2 = QtWidgets.QLabel(IsortFormattingDialog)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout.addWidget(self.label_2)
        self.statusFilterComboBox = QtWidgets.QComboBox(IsortFormattingDialog)
        self.statusFilterComboBox.setMinimumSize(QtCore.QSize(150, 0))
        self.statusFilterComboBox.setSizeAdjustPolicy(QtWidgets.QComboBox.SizeAdjustPolicy.AdjustToMinimumContentsLengthWithIcon)
        self.statusFilterComboBox.setObjectName("statusFilterComboBox")
        self.horizontalLayout.addWidget(self.statusFilterComboBox)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.resultsList = QtWidgets.QTreeWidget(IsortFormattingDialog)
        self.resultsList.setAlternatingRowColors(True)
        self.resultsList.setRootIsDecorated(False)
        self.resultsList.setItemsExpandable(False)
        self.resultsList.setObjectName("resultsList")
        self.verticalLayout.addWidget(self.resultsList)
        self.statisticsGroup = QtWidgets.QGroupBox(IsortFormattingDialog)
        self.statisticsGroup.setObjectName("statisticsGroup")
        self.gridLayout = QtWidgets.QGridLayout(self.statisticsGroup)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(self.statisticsGroup)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.totalCountLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.totalCountLabel.setText("0")
        self.totalCountLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.totalCountLabel.setObjectName("totalCountLabel")
        self.gridLayout.addWidget(self.totalCountLabel, 0, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(183, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem1, 0, 2, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.statisticsGroup)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 0, 3, 1, 1)
        self.skippedCountLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.skippedCountLabel.setText("0")
        self.skippedCountLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.skippedCountLabel.setObjectName("skippedCountLabel")
        self.gridLayout.addWidget(self.skippedCountLabel, 0, 4, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(182, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem2, 0, 5, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.statisticsGroup)
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 0, 6, 1, 1)
        self.failuresCountLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.failuresCountLabel.setText("0")
        self.failuresCountLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.failuresCountLabel.setObjectName("failuresCountLabel")
        self.gridLayout.addWidget(self.failuresCountLabel, 0, 7, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.statisticsGroup)
        self.label_6.setObjectName("label_6")
        self.gridLayout.addWidget(self.label_6, 1, 0, 1, 1)
        self.processedCountLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.processedCountLabel.setText("0")
        self.processedCountLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.processedCountLabel.setObjectName("processedCountLabel")
        self.gridLayout.addWidget(self.processedCountLabel, 1, 1, 1, 1)
        self.reformattedLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.reformattedLabel.setObjectName("reformattedLabel")
        self.gridLayout.addWidget(self.reformattedLabel, 1, 3, 1, 1)
        self.reformattedCountLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.reformattedCountLabel.setText("0")
        self.reformattedCountLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.reformattedCountLabel.setObjectName("reformattedCountLabel")
        self.gridLayout.addWidget(self.reformattedCountLabel, 1, 4, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.statisticsGroup)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 1, 6, 1, 1)
        self.unchangedCountLabel = QtWidgets.QLabel(self.statisticsGroup)
        self.unchangedCountLabel.setText("0")
        self.unchangedCountLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.unchangedCountLabel.setObjectName("unchangedCountLabel")
        self.gridLayout.addWidget(self.unchangedCountLabel, 1, 7, 1, 1)
        self.verticalLayout.addWidget(self.statisticsGroup)
        self.progressBar = QtWidgets.QProgressBar(IsortFormattingDialog)
        self.progressBar.setObjectName("progressBar")
        self.verticalLayout.addWidget(self.progressBar)
        self.buttonBox = QtWidgets.QDialogButtonBox(IsortFormattingDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Close)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(IsortFormattingDialog)
        QtCore.QMetaObject.connectSlotsByName(IsortFormattingDialog)
        IsortFormattingDialog.setTabOrder(self.resultsList, self.statusFilterComboBox)

    def retranslateUi(self, IsortFormattingDialog):
        _translate = QtCore.QCoreApplication.translate
        IsortFormattingDialog.setWindowTitle(_translate("IsortFormattingDialog", "Sort Imports with isort"))
        self.label_2.setText(_translate("IsortFormattingDialog", "Status Filter:"))
        self.statusFilterComboBox.setToolTip(_translate("IsortFormattingDialog", "Select the status of items to be shown (empty for all)."))
        self.resultsList.setSortingEnabled(True)
        self.resultsList.headerItem().setText(0, _translate("IsortFormattingDialog", "Status"))
        self.resultsList.headerItem().setText(1, _translate("IsortFormattingDialog", "File Name"))
        self.statisticsGroup.setTitle(_translate("IsortFormattingDialog", "Statistics"))
        self.label.setText(_translate("IsortFormattingDialog", "Total Files:"))
        self.label_3.setText(_translate("IsortFormattingDialog", "Skipped:"))
        self.label_5.setText(_translate("IsortFormattingDialog", "Failures:"))
        self.label_6.setText(_translate("IsortFormattingDialog", "Processed:"))
        self.reformattedLabel.setText(_translate("IsortFormattingDialog", "Resorted:"))
        self.label_4.setText(_translate("IsortFormattingDialog", "Unchanged:"))
        self.progressBar.setFormat(_translate("IsortFormattingDialog", "%v/%m Files"))



# Form implementation generated from reading ui file 'src/eric7/Plugins/VcsPlugins/vcsGit/GitWorktreeDialog.ui'
#
# Created by: PyQt6 UI code generator 6.3.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_GitWorktreeDialog(object):
    def setupUi(self, GitWorktreeDialog):
        GitWorktreeDialog.setObjectName("GitWorktreeDialog")
        GitWorktreeDialog.resize(800, 500)
        GitWorktreeDialog.setProperty("sizeGripEnabled", True)
        self.verticalLayout = QtWidgets.QVBoxLayout(GitWorktreeDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.actionsButton = QtWidgets.QToolButton(GitWorktreeDialog)
        self.actionsButton.setPopupMode(QtWidgets.QToolButton.ToolButtonPopupMode.InstantPopup)
        self.actionsButton.setObjectName("actionsButton")
        self.horizontalLayout.addWidget(self.actionsButton)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.expireCheckBox = QtWidgets.QCheckBox(GitWorktreeDialog)
        self.expireCheckBox.setObjectName("expireCheckBox")
        self.horizontalLayout.addWidget(self.expireCheckBox)
        self.expireDateTimeEdit = QtWidgets.QDateTimeEdit(GitWorktreeDialog)
        self.expireDateTimeEdit.setEnabled(False)
        self.expireDateTimeEdit.setCalendarPopup(True)
        self.expireDateTimeEdit.setObjectName("expireDateTimeEdit")
        self.horizontalLayout.addWidget(self.expireDateTimeEdit)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.worktreeList = QtWidgets.QTreeWidget(GitWorktreeDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(2)
        sizePolicy.setHeightForWidth(self.worktreeList.sizePolicy().hasHeightForWidth())
        self.worktreeList.setSizePolicy(sizePolicy)
        self.worktreeList.setAlternatingRowColors(True)
        self.worktreeList.setSelectionMode(QtWidgets.QAbstractItemView.SelectionMode.SingleSelection)
        self.worktreeList.setRootIsDecorated(False)
        self.worktreeList.setItemsExpandable(False)
        self.worktreeList.setExpandsOnDoubleClick(False)
        self.worktreeList.setObjectName("worktreeList")
        self.verticalLayout.addWidget(self.worktreeList)
        self.errorGroup = QtWidgets.QGroupBox(GitWorktreeDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.errorGroup.sizePolicy().hasHeightForWidth())
        self.errorGroup.setSizePolicy(sizePolicy)
        self.errorGroup.setObjectName("errorGroup")
        self._2 = QtWidgets.QVBoxLayout(self.errorGroup)
        self._2.setObjectName("_2")
        self.errors = QtWidgets.QTextEdit(self.errorGroup)
        self.errors.setReadOnly(True)
        self.errors.setAcceptRichText(False)
        self.errors.setObjectName("errors")
        self._2.addWidget(self.errors)
        self.verticalLayout.addWidget(self.errorGroup)
        self.buttonBox = QtWidgets.QDialogButtonBox(GitWorktreeDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Close)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(GitWorktreeDialog)
        self.expireCheckBox.toggled['bool'].connect(self.expireDateTimeEdit.setEnabled) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(GitWorktreeDialog)
        GitWorktreeDialog.setTabOrder(self.actionsButton, self.expireCheckBox)
        GitWorktreeDialog.setTabOrder(self.expireCheckBox, self.expireDateTimeEdit)
        GitWorktreeDialog.setTabOrder(self.expireDateTimeEdit, self.worktreeList)
        GitWorktreeDialog.setTabOrder(self.worktreeList, self.errors)

    def retranslateUi(self, GitWorktreeDialog):
        _translate = QtCore.QCoreApplication.translate
        GitWorktreeDialog.setWindowTitle(_translate("GitWorktreeDialog", "Git Worktree"))
        self.actionsButton.setToolTip(_translate("GitWorktreeDialog", "Select action from menu"))
        self.expireCheckBox.setToolTip(_translate("GitWorktreeDialog", "Select to annotate missing worktrees older than the entered date and time as prunable."))
        self.expireCheckBox.setText(_translate("GitWorktreeDialog", "Expire:"))
        self.expireDateTimeEdit.setToolTip(_translate("GitWorktreeDialog", "All missing worktrees older than the entered date and time will be annotated as prunable."))
        self.expireDateTimeEdit.setDisplayFormat(_translate("GitWorktreeDialog", "yyyy-MM-dd HH:mm:ss"))
        self.worktreeList.setSortingEnabled(True)
        self.worktreeList.headerItem().setText(0, _translate("GitWorktreeDialog", "Name"))
        self.worktreeList.headerItem().setText(1, _translate("GitWorktreeDialog", "Path"))
        self.worktreeList.headerItem().setText(2, _translate("GitWorktreeDialog", "Commit"))
        self.worktreeList.headerItem().setText(3, _translate("GitWorktreeDialog", "Branch"))
        self.errorGroup.setTitle(_translate("GitWorktreeDialog", "Errors"))
